possible

# XMLRésuméLibrary: User Guide

phone | Element Reference | postalCode

## Name

possible — The highest possible score in a GPA

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `possible` element contains a number that indicates the highest possible score that can be attained in a GPA. In other words, a “perfect” score.

### Parents

`possible` may be contained in these elements: `gpa`

## See Also

`score`.

## Examples

For examples, see `gpa`.

phone | Element Reference | postalCode